@@ -40,11 +40,12 @@ my $args = "@ARGV";
 $args =~ s/(?:^|\s)(\d+)\s*\-\s*(\d+)(?:$|\s)/ $1-$2 /g;
 $args =~ s/,/ /g;
 for (split ' ', $args) {
-	if (/^\-([enrv]+$)/) {
+	if (/^\-([ehnrv]+$)/) {
 		my $x = $1;
 		$verbose = 1, $errors = 1 if $x =~ /v/;
 		$errors = 1 if $x =~ /e/;
 		$noaction = 1 if $x =~ /n/;
+		usage() if $x =~ /h/;
 	} elsif (/^(\d*)-(\d+)$/) {
 		push @numtest, $_ for ($1 || 1 .. $2);
 	} elsif (/^(\d+)$/) {
@@ -473,5 +474,4 @@ less $T/tests/test_plain :			# even watch growing files without +F
 ~ test=a
 less $T/tests/test.jar			# support for jar files git #8,22
 ~ .* META-INF/
-###    .lessfilter not implemented git #23 (open)
 ###    colorize markdown files (mdcat) on MacOSX and iTerm2 (see git #48)
